CrashlyticsUtil class abstract

Constructors

CrashlyticsUtil()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(String message) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordError(dynamic exception, StackTrace stack, {dynamic reason, Iterable<Object>? information, bool? printDetails}) Future<void>
setCrashlyticsCollectionEnabled(bool enabled) Future<void>
setCustomKey(String key, Object value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CrashlyticsUtil
no setter