NotificationsData class abstract

Available extensions
Annotations
  • @freezed

Constructors

NotificationsData({required Data data})
const
factory
NotificationsData.fromJson(Map<String, dynamic> json)
factory
NotificationsData.fromRawJson(String str)
factory
NotificationsData.sample()
factory

Properties

copyWith → $NotificationsDataCopyWith<NotificationsData>
Create a copy of NotificationsData with the given fields replaced by the non-null parameter values.
no setterinherited
data Data
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_NotificationsData value)) → TResult

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NotificationsData value)?) → TResult?

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NotificationsData value)?, {required TResult orElse()}) → TResult

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Data data)?, {required TResult orElse()}) → TResult

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this NotificationsData to a JSON map.
inherited
toRawJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Data data)) → TResult

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Data data)?) → TResult?

Available on NotificationsData, provided by the NotificationsDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited