TimeCode class abstract

Available extensions
Annotations
  • @freezed

Constructors

TimeCode({required String title, required String startTime, required String endTime})
const
factory
TimeCode.fromJson(Map<String, dynamic> json)
factory
TimeCode.fromRawJson(String str)
factory

Properties

copyWith → $TimeCodeCopyWith<TimeCode>
Create a copy of TimeCode with the given fields replaced by the non-null parameter values.
no setterinherited
endTime String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String
no setterinherited
title String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TimeCode value)) → TResult

Available on TimeCode, provided by the TimeCodePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TimeCode value)?) → TResult?

Available on TimeCode, provided by the TimeCodePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TimeCode value)?, {required TResult orElse()}) → TResult

Available on TimeCode, provided by the TimeCodePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String title, String startTime, String endTime)?, {required TResult orElse()}) → TResult

Available on TimeCode, provided by the TimeCodePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TimeCode to a JSON map.
inherited
toRawJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String title, String startTime, String endTime)) → TResult

Available on TimeCode, provided by the TimeCodePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String title, String startTime, String endTime)?) → TResult?

Available on TimeCode, provided by the TimeCodePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited