Factory<T> class abstract

Constructors

Factory(DependencyBuilder<T> builder)

Properties

builder → DependencyBuilder<T>
final
hashCode → int
The hash code for this object.
no setterinherited
instance → T
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

provider<T>(DependencyBuilder<T> builder) → Factory<T>
singleton<T>(DependencyBuilder<T> builder) → Factory<T>