ImgurUploadResponse class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ImgurUploadResponse({int? status, bool? success, ImgurUploadData? data})
-
constfactory
-
ImgurUploadResponse.fromJson(Map<
String, dynamic> json) -
factory
- ImgurUploadResponse.fromRawJson(String str)
-
factory
Properties
-
copyWith
→ $ImgurUploadResponseCopyWith<
ImgurUploadResponse> -
Create a copy of ImgurUploadResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- data → ImgurUploadData?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
no setterinherited
- success → bool?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ImgurUploadResponse value)) → TResult -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ImgurUploadResponse value)?) → TResult? -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ImgurUploadResponse value)?, {required TResult orElse()}) → TResult -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int? status, bool? success, ImgurUploadData? data)?, {required TResult orElse()}) → TResult -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ImgurUploadResponse to a JSON map.
inherited
-
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int? status, bool? success, ImgurUploadData? data)) → TResult -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int? status, bool? success, ImgurUploadData? data)?) → TResult? -
Available on ImgurUploadResponse, provided by the ImgurUploadResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited